@@ -1,7 +1,8 @@
 ### `checkVersions` and `add.packages.miniCRAN` require an existing miniCRAN repo
 
 # Specify list of packages to download
-revolution <- c(CRAN = getOption("miniCRAN.mran"))
+revolution <- c(CRAN = getOption("minicran.mran"))
+revolution
 pkgs <- c("foreach")
 pkgTypes <- c("source", "win.binary")
 
